Changelog — django-frontend-skeleton 0.7.1 documentation

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 0.7.1 documentation »

# Changelog

## 0.7.1

- Update to Twitter Bootstrap 2.3.2 (Twitter Bootstrap)

## 0.7.0

- Added jQuery 2.0.0 (HTML5 Boilerplate)
- Added SKELETON_STATIC_URL for optional dedicated static server/CDN setting
- Added Road Map

## 0.6.0

- Remove Google Analytics protocol check (HTML5 Boilerplate)
- Update Normalize.css to 1.1.1 (HTML5 Boilerplate)
- Update to Twitter Bootstrap 2.3.1 (Twitter Bootstrap)
- Added H5BP_GA_SETDOMAINNAME and H5BP_GA_SETALLOWLINKER for optional Google Analytics customization (HTML5 Boilerplate)
- iOS-Orientationchange-Fix moved out of base.html
- iOS-Orientationchange-Fix now {% skeleton_ios_fix %}
- Created ‘skeleton’ template tag library

## 0.5.0

- Update to jQuery 1.9.1 (HTML5 Boilerplate)
- Update to Twitter Bootstrap 2.3.0 (Twitter Bootstrap)

## 0.4.0

- Update to jQuery 1.9.0 (HTML5 Boilerplate)
- Update to Normalize.css 1.1.0 (HTML5 Boilerplate)
- Update h5bp.css (HTML5 Boilerplate)
- Include changelog

## 0.3.0

- Namespace static files under ‘skeleton’
- Remove trailing slash from MANIFEST.in
- Documentation update/improvement

## 0.2.0

- Update to Twitter Bootstrap 2.2.2 (Twitter Bootstrap)
- Fix Glyphicons URL (Twitter Boostrap)
- Add documentation
- Minimize Readme

## 0.1.0

- Initial release

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 0.7.1 documentation »